@@ -55,12 +55,8 @@ def parse_metadata_json(conversations):
     return conversations
 
 
-def pull(org_id: int, lang_code: str, start: str, end: Optional[str] = "now",
-         call_quantity: Optional[int] = 0, output_json: Optional[str] = ""):
-
-    if output_json and os.path.exists(output_json):
-        raise FileExistsError(f"{output_json} already present")
-
+def get_call_list(org_id: int, lang_code: str, start: str, end: Optional[str] = "now",
+         call_quantity: Optional[int] = 0):
     start = convert_date(start)
     end = convert_date(end)
 
@@ -82,6 +78,16 @@ def pull(org_id: int, lang_code: str, start: str, end: Optional[str] = "now",
         call_list.append(call)
 
     print(f"pulled data in {time.time() - proc_start_time:.2f}s")
+    return call_list
+
+
+def pull(org_id: int, lang_code: str, start: str, end: Optional[str] = "now",
+         call_quantity: Optional[int] = 0, output_json: Optional[str] = ""):
+
+    if output_json and os.path.exists(output_json):
+        raise FileExistsError(f"{output_json} already present")
+
+    call_list = get_call_list(org_id, lang_code, start, end=end, call_quantity=call_quantity)
 
     if output_json:
         print(f"Writing {len(call_list)} call(s) to {output_json}")
